@@ -1,6 +1,6 @@
 
 import orjson as _orjson
-
+import json as defaultjson
 from os import PathLike
 from pydantic import BaseModel
 from typing import Dict, Any, List, Union, overload
@@ -323,6 +323,24 @@ class SimdJson(JsonBase):
         return _simdjson.loads(data, *args, **kwargs)
 
 
+class DefaultJson(JsonBase):
+    
+    @classmethod
+    def _encode(cls, obj: Dict[Any, Any], *args, default: Dict[Any, Any] = None, **kwargs) -> str:
+        return defaultjson.dumps(obj, default=default, *args, **kwargs)
+    
+    @classmethod
+    def _decode(cls, data: Union[str, bytes], *args, **kwargs) -> Union[Dict[Any, Any], List[str]]:
+        return defaultjson.loads(data, *args, **kwargs)
+    
+    @classmethod
+    async def _async_encode(cls, obj: Dict[Any, Any], *args, default: Dict[Any, Any] = None, **kwargs) -> str:
+        return defaultjson.dumps(obj, default=default, *args, **kwargs)
+    
+    @classmethod
+    async def _async_decode(cls, data: Union[str, bytes], *args, **kwargs) -> Union[Dict[Any, Any], List[str]]:
+        return defaultjson.loads(data, *args, **kwargs)
+
 
 class Json(JsonBase):
     parser: _simdjson.Parser = SimdJson.parser
@@ -350,4 +368,4 @@ class Json(JsonBase):
     @classmethod
     async def _async_decode(cls, data: Union[str, bytes], *args, **kwargs) -> Union[Dict[Any, Any], List[str]]:
         if cls.parser_enabled: return SimdJson.parse(data, *args, **kwargs)
-        return await OrJson._async_decode(data, *args, **kwargs)
\ No newline at end of file
+        return await OrJson._async_decode(data, *args, **kwargs)
